pub struct ProtocolHandler { /* private fields */ }Expand description
The main protocol handler that dispatches incoming JSON-RPC messages.
Implementations
Sourceimpl ProtocolHandler
impl ProtocolHandler
Sourcepub fn new(session: Arc<Mutex<SessionManager>>) -> Self
pub fn new(session: Arc<Mutex<SessionManager>>) -> Self
Create a new protocol handler with the given session manager.
Sourcepub fn with_mode(session: Arc<Mutex<SessionManager>>, mode: MemoryMode) -> Self
pub fn with_mode(session: Arc<Mutex<SessionManager>>, mode: MemoryMode) -> Self
Create a new protocol handler with a specific memory mode.
Sourcepub fn shutdown_requested(&self) -> bool
pub fn shutdown_requested(&self) -> bool
Returns true once a shutdown request has been handled.
Sourcepub async fn handle_message(&self, msg: JsonRpcMessage) -> Option<Value>
pub async fn handle_message(&self, msg: JsonRpcMessage) -> Option<Value>
Handle an incoming JSON-RPC message and optionally return a response.