MCP tool implementations — the primary way LLMs interact with memory.
Re-exports
pub use registry::ToolRegistry;
Modules
- conversation_
log - Tool: conversation_log — Log user prompts and agent responses into the conversation thread.
- memory_
add - Tool: memory_add — Add a cognitive event to the memory graph.
- memory_
causal - Tool: memory_causal — Impact analysis: what depends on this node?
- memory_
context - Tool: memory_context — Get full context (subgraph) around a node.
- memory_
correct - Tool: memory_correct — Record a correction to a previous belief.
- memory_
evidence - Tool: memory_evidence — Get detailed evidence for a claim from memory.
- memory_
ground - Tool: memory_ground — Verify a claim has memory backing (anti-hallucination).
- memory_
quality - Tool: memory_quality — Graph quality and reliability summary.
- memory_
query - Tool: memory_query — Pattern query for matching nodes.
- memory_
resolve - Tool: memory_resolve — Follow supersedes chain to get the latest version.
- memory_
session_ resume - Tool: memory_session_resume — Load context from previous sessions.
- memory_
similar - Tool: memory_similar — Find semantically similar memories.
- memory_
stats - Tool: memory_stats — Get statistics about the memory graph.
- memory_
suggest - Tool: memory_suggest — Find similar memories for corrections/suggestions.
- memory_
temporal - Tool: memory_temporal — Compare knowledge across time periods.
- memory_
traverse - Tool: memory_traverse — Walk the graph from a starting node.
- memory_
workspace_ add - Tool: memory_workspace_add — Add an .amem file to a workspace.
- memory_
workspace_ compare - Tool: memory_workspace_compare — Compare a topic across memory contexts.
- memory_
workspace_ create - Tool: memory_workspace_create — Create a multi-memory workspace.
- memory_
workspace_ list - Tool: memory_workspace_list — List loaded memory contexts in a workspace.
- memory_
workspace_ query - Tool: memory_workspace_query — Query across all memory contexts in a workspace.
- memory_
workspace_ xref - Tool: memory_workspace_xref — Cross-reference a topic across memory contexts.
- registry
- Tool registration and dispatch.
- session_
end - Tool: session_end — End a session and optionally create an episode summary.
- session_
start - Tool: session_start — Begin a new interaction session with prior context.